@@ -21,6 +21,7 @@
 #include <math.h>
 #include <stdlib.h>
 
+#include <limits>
 #include <new>
 
 #include <QApplication>
@@ -129,7 +130,7 @@ Kwave::MainWidget::MainWidget(QWidget *parent, Kwave::FileContext &context,
     // - lower dock
     // - overview
     // - horizontal scroll bar
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    QVBoxLayout *topLayout = new(std::nothrow) QVBoxLayout(this);
     Q_ASSERT(topLayout);
     if (!topLayout) return;
 
@@ -156,7 +157,7 @@ Kwave::MainWidget::MainWidget(QWidget *parent, Kwave::FileContext &context,
 
     // -- overview widget --
 
-    m_overview = new Kwave::OverViewWidget(*signal_manager, this);
+    m_overview = new(std::nothrow) Kwave::OverViewWidget(*signal_manager, this);
     Q_ASSERT(m_overview);
     if (!m_overview) return;
     m_overview->setMinimumHeight(m_overview->sizeHint().height());
@@ -173,7 +174,7 @@ Kwave::MainWidget::MainWidget(QWidget *parent, Kwave::FileContext &context,
 
     // -- horizontal scrollbar --
 
-    m_horizontal_scrollbar = new QScrollBar(this);
+    m_horizontal_scrollbar = new(std::nothrow) QScrollBar(this);
     Q_ASSERT(m_horizontal_scrollbar);
     if (!m_horizontal_scrollbar) return;
     m_horizontal_scrollbar->setOrientation(Qt::Horizontal);
@@ -552,9 +553,10 @@ void Kwave::MainWidget::refreshHorizontalScrollBar()
 	// max                            = length   / f - page
 	// pos  = (m_offset / length) * x = m_offset / f
 
+	const sample_index_t int_max = std::numeric_limits<int>::max();
 	const sample_index_t f = qMax(
 	    sample_index_t(1),
-	    sample_index_t((length + INT_MAX - 1) / INT_MAX)
+	    sample_index_t((length + int_max - 1) / int_max)
 	);
 	int page    = Kwave::toInt(visible  / f);
 	int min     = 0;
@@ -580,10 +582,11 @@ void Kwave::MainWidget::refreshHorizontalScrollBar()
 void Kwave::MainWidget::horizontalScrollBarMoved(int newval)
 {
     // new offset = pos * f
-    sample_index_t length  = m_context.signalManager()->length();
+    const sample_index_t length  = m_context.signalManager()->length();
+    const sample_index_t int_max = std::numeric_limits<int>::max();
     const sample_index_t f = qMax(
 	sample_index_t(1),
-	sample_index_t((length + INT_MAX - 1) / INT_MAX)
+	sample_index_t((length + int_max - 1) / int_max)
     );
     const sample_index_t pos = newval * f;
     setOffset(pos);
@@ -742,7 +745,8 @@ void Kwave::MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
                static_cast<double>(width);
 
     // ensure that pixel coordinates are within signed int range
-    min_zoom = qMax(min_zoom, static_cast<double>(length) / double(INT_MAX));
+    min_zoom = qMax(min_zoom, static_cast<double>(length) /
+                              double(std::numeric_limits<int>::max()));
 
     if (m_zoom < min_zoom) m_zoom = min_zoom;
     if (m_zoom > max_zoom) m_zoom = max_zoom;
@@ -931,7 +935,7 @@ int Kwave::MainWidget::loadLabels(const QString &filename)
 	QUrl(), LABEL_LIST_EXT);
 	if (!dlg) return -1;
 	dlg->setWindowTitle(i18n("Load Labels"));
-	if (dlg->exec() != QDialog::Accepted) {
+	if ((dlg->exec() != QDialog::Accepted) || !dlg) {
 	    delete dlg;
 	    return 0;
 	} else {
@@ -967,7 +971,7 @@ int Kwave::MainWidget::saveLabels(const QString &filename)
 	    this, url, LABEL_LIST_EXT);
 	if (!dlg) return 0;
 	dlg->setWindowTitle(i18n("Save Labels"));
-	if (dlg->exec() != QDialog::Accepted) {
+	if ((dlg->exec() != QDialog::Accepted) || !dlg) {
 	    delete dlg;
 	    return -1;
 	}
@@ -1045,7 +1049,7 @@ bool Kwave::MainWidget::labelProperties(Kwave::Label &label)
     while (true) {
 	// create and prepare the dialog
 	Kwave::LabelPropertiesWidget *dlg =
-	    new Kwave::LabelPropertiesWidget(this);
+	    new(std::nothrow) Kwave::LabelPropertiesWidget(this);
 	Q_ASSERT(dlg);
 	if (!dlg) return false;
 	dlg->setLabelIndex(index);
@@ -1055,7 +1059,7 @@ bool Kwave::MainWidget::labelProperties(Kwave::Label &label)
 
 	// execute the dialog
 	accepted = (dlg->exec() == QDialog::Accepted);
-	if (!accepted) {
+	if (!accepted || !dlg) {
 	    // user pressed "cancel"
 	    delete dlg;
 	    break;
